@@ -32,7 +32,7 @@
 
 #include <config.h>
 
-#ident "$Id: faillog.c 2507 2009-03-13 22:49:20Z nekral-guest $"
+#ident "$Id: faillog.c 2851 2009-04-30 21:39:38Z nekral-guest $"
 
 #include <getopt.h>
 #include <pwd.h>
@@ -42,9 +42,11 @@
 #include <time.h>
 #include <assert.h>
 #include "defines.h"
-#include "exitcodes.h"
 #include "faillog.h"
 #include "prototypes.h"
+/*@-exitarg@*/
+#include "exitcodes.h"
+
 /*
  * Global variables
  */
@@ -85,7 +87,7 @@ static void usage (void)
 	exit (E_USAGE);
 }
 
-static void print_one (const struct passwd *pw, bool force)
+static void print_one (/*@null@*/const struct passwd *pw, bool force)
 {
 	static bool once = false;
 	struct tm *tm;
@@ -105,15 +107,16 @@ static void print_one (const struct passwd *pw, bool force)
 	offset = pw->pw_uid * sizeof (fl);
 	if (offset <= (statbuf.st_size - sizeof (fl))) {
 		/* fseeko errors are not really relevant for us. */
-		assert ( fseeko (fail, offset, SEEK_SET) == 0 );
+		int err = fseeko (fail, offset, SEEK_SET);
+		assert (0 == err);
 		/* faillog is a sparse file. Even if no entries were
 		 * entered for this user, which should be able to get the
 		 * empty entry in this case.
 		 */
 		if (fread ((char *) &fl, sizeof (fl), 1, fail) != 1) {
 			fprintf (stderr,
-			         _("faillog: Failed to get the entry for UID %d\n"),
-			         pw->pw_uid);
+			         _("faillog: Failed to get the entry for UID %lu\n"),
+			         (unsigned long int)pw->pw_uid);
 			return;
 		}
 	} else {
@@ -204,15 +207,16 @@ static bool reset_one (uid_t uid)
 	offset = uid * sizeof (fl);
 	if (offset <= (statbuf.st_size - sizeof (fl))) {
 		/* fseeko errors are not really relevant for us. */
-		assert ( fseeko (fail, offset, SEEK_SET) == 0 );
+		int err = fseeko (fail, offset, SEEK_SET);
+		assert (0 == err);
 		/* faillog is a sparse file. Even if no entries were
 		 * entered for this user, which should be able to get the
 		 * empty entry in this case.
 		 */
 		if (fread ((char *) &fl, sizeof (fl), 1, fail) != 1) {
 			fprintf (stderr,
-			         _("faillog: Failed to get the entry for UID %d\n"),
-			         uid);
+			         _("faillog: Failed to get the entry for UID %lu\n"),
+			         (unsigned long int)uid);
 			return true;
 		}
 	} else {
@@ -241,8 +245,8 @@ static bool reset_one (uid_t uid)
 	}
 
 	fprintf (stderr,
-	         _("faillog: Failed to reset fail count for UID %d\n"),
-	         uid);
+	         _("faillog: Failed to reset fail count for UID %lu\n"),
+	         (unsigned long int)uid);
 	return true;
 }
 
@@ -290,15 +294,16 @@ static bool setmax_one (uid_t uid, int max)
 	offset = (off_t) uid * sizeof (fl);
 	if (offset <= (statbuf.st_size - sizeof (fl))) {
 		/* fseeko errors are not really relevant for us. */
-		assert ( fseeko (fail, offset, SEEK_SET) == 0 );
+		int err = fseeko (fail, offset, SEEK_SET);
+		assert (0 == err);
 		/* faillog is a sparse file. Even if no entries were
 		 * entered for this user, which should be able to get the
 		 * empty entry in this case.
 		 */
 		if (fread ((char *) &fl, sizeof (fl), 1, fail) != 1) {
 			fprintf (stderr,
-			         _("faillog: Failed to get the entry for UID %d\n"),
-			         uid);
+			         _("faillog: Failed to get the entry for UID %lu\n"),
+			         (unsigned long int)uid);
 			return true;
 		}
 	} else {
@@ -323,13 +328,13 @@ static bool setmax_one (uid_t uid, int max)
 
 	if (   (fseeko (fail, offset, SEEK_SET) == 0)
 	    && (fwrite ((char *) &fl, sizeof (fl), 1, fail) == 1)) {
-		fflush (fail);
+		(void) fflush (fail);
 		return false;
 	}
 
 	fprintf (stderr,
-	         _("faillog: Failed to set max for UID %d\n"),
-	         uid);
+	         _("faillog: Failed to set max for UID %lu\n"),
+	         (unsigned long int)uid);
 	return true;
 }
 
@@ -380,15 +385,16 @@ static bool set_locktime_one (uid_t uid, long locktime)
 	offset = (off_t) uid * sizeof (fl);
 	if (offset <= (statbuf.st_size - sizeof (fl))) {
 		/* fseeko errors are not really relevant for us. */
-		assert ( fseeko (fail, offset, SEEK_SET) == 0 );
+		int err = fseeko (fail, offset, SEEK_SET);
+		assert (0 == err);
 		/* faillog is a sparse file. Even if no entries were
 		 * entered for this user, which should be able to get the
 		 * empty entry in this case.
 		 */
 		if (fread ((char *) &fl, sizeof (fl), 1, fail) != 1) {
 			fprintf (stderr,
-			         _("faillog: Failed to get the entry for UID %d\n"),
-			         uid);
+			         _("faillog: Failed to get the entry for UID %lu\n"),
+			         (unsigned long int)uid);
 			return true;
 		}
 	} else {
@@ -411,15 +417,15 @@ static bool set_locktime_one (uid_t uid, long locktime)
 
 	fl.fail_locktime = locktime;
 
-	if (fseeko (fail, offset, SEEK_SET) == 0
-	    && fwrite ((char *) &fl, sizeof (fl), 1, fail) == 1) {
-		fflush (fail);
+	if (   (fseeko (fail, offset, SEEK_SET) == 0)
+	    && (fwrite ((char *) &fl, sizeof (fl), 1, fail) == 1)) {
+		(void) fflush (fail);
 		return false;
 	}
 
 	fprintf (stderr,
-	         _("faillog: Failed to set locktime for UID %d\n"),
-	         uid);
+	         _("faillog: Failed to set locktime for UID %lu\n"),
+	         (unsigned long int)uid);
 	return true;
 }
 
@@ -494,7 +500,7 @@ int main (int argc, char **argv)
 					fprintf (stderr,
 					         _("%s: invalid numeric argument '%s'\n"),
 					         "faillog", optarg);
-					usage ();
+					exit (E_BAD_ARG);
 				}
 				lflg = true;
 				break;
@@ -503,7 +509,7 @@ int main (int argc, char **argv)
 					fprintf (stderr,
 					         _("%s: invalid numeric argument '%s'\n"),
 					         "faillog", optarg);
-					usage ();
+					exit (E_BAD_ARG);
 				}
 				mflg = true;
 				break;
@@ -515,7 +521,7 @@ int main (int argc, char **argv)
 					fprintf (stderr,
 					         _("%s: invalid numeric argument '%s'\n"),
 					         "faillog", optarg);
-					usage ();
+					exit (E_BAD_ARG);
 				}
 				seconds = (time_t) days * DAY;
 				tflg = true;
@@ -546,7 +552,7 @@ int main (int argc, char **argv)
 						fprintf (stderr,
 						         _("lastlog: Unknown user or range: %s\n"),
 						         optarg);
-						exit (EXIT_FAILURE);
+						exit (E_BAD_ARG);
 					}
 				}
 
@@ -575,7 +581,7 @@ int main (int argc, char **argv)
 		fprintf (stderr,
 		         _("faillog: Cannot open %s: %s\n"),
 		         FAILLOG_FILE, strerror (errno));
-		exit (EXIT_FAILURE);
+		exit (E_NOPERM);
 	}
 
 	/* Get the size of the faillog */
@@ -583,7 +589,7 @@ int main (int argc, char **argv)
 		fprintf (stderr,
 		         _("faillog: Cannot get the size of %s: %s\n"),
 		         FAILLOG_FILE, strerror (errno));
-		exit (EXIT_FAILURE);
+		exit (E_NOPERM);
 	}
 
 	if (lflg) {
@@ -604,6 +610,6 @@ int main (int argc, char **argv)
 
 	fclose (fail);
 
-	exit (errors ? EXIT_FAILURE : EXIT_SUCCESS);
+	exit (errors ? E_NOPERM : E_SUCCESS);
 }
 
