@@ -53,7 +53,7 @@
 
 #include <config.h>
 
-#ident "$Id: su.c 2899 2009-05-10 18:20:41Z nekral-guest $"
+#ident "$Id: su.c 2963 2009-05-21 11:58:59Z nekral-guest $"
 
 #include <getopt.h>
 #include <grp.h>
@@ -161,7 +161,7 @@ static bool restricted_shell (const char *shellstr)
 
 static void su_failure (const char *tty)
 {
-	sulog (tty, 0, oldname, name);	/* log failed attempt */
+	sulog (tty, false, oldname, name);	/* log failed attempt */
 #ifdef USE_SYSLOG
 	if (getdef_bool ("SYSLOG_SU_ENAB")) {
 		SYSLOG (((0 != pwent.pw_uid) ? LOG_INFO : LOG_NOTICE,
@@ -425,13 +425,8 @@ int main (int argc, char **argv)
 	 * Get the tty name. Entries will be logged indicating that the user
 	 * tried to change to the named new user from the current terminal.
 	 */
-	cp = ttyname (0);
-	if ((isatty (0) != 0) && (NULL != cp)) {
-		if (strncmp (cp, "/dev/", 5) == 0) {
-			tty = cp + 5;
-		} else {
-			tty = cp;
-		}
+	tty = ttyname (0);
+	if ((isatty (0) != 0) && (NULL != tty)) {
 #ifndef USE_PAM
 		is_console = console (tty);
 #endif
